@@ -1,6 +1,6 @@
 define([
     'base/js/namespace',
-    'base/js/events'
+	'base/js/events'
 ], function(Jupyter) {
 
     var Notebook = require('notebook/js/notebook').Notebook
@@ -159,7 +159,23 @@ define([
 			});
 			return true;
 		});        
-    };
+	};
+	
+	var load_css = function(path) {
+		var link = document.createElement("link");
+		link.href = path;
+		link.type = "text/css";
+		document.getElementsByTagName("head")[0].appendChild(link);
+		console.log("==============load css: " + path + "==========");
+	};
+
+	var load_js = function(path) {
+		var script = document.createElement("script");
+		script.type = "text/javascript";
+		script.href = path;
+		document.getElementsByTagName("body")[0].appendChild(script);
+		console.log("==============load js: " + path + "==========");
+	}
 
     var dolphinDB_button = function() {
         var action = {
@@ -174,10 +190,22 @@ define([
         Jupyter.toolbar.add_buttons_group([full_action_name]);
     };
 
+	var prefix = '/home/hzzuo/.local/share/jupyter/nbextensions/dolphindb_extension/';
+
     var load_ipython_extension = function() {
         if(kernel.name === 'dolphindb') {
-            console.log(log_prefix + 'DolphinDB kernel is available -- DolphinDB_Extension initializing ');
-            dolphinDB_button();
+			console.log(log_prefix + 'DolphinDB kernel is available -- DolphinDB_Extension initializing ');
+			// css
+			// load_css(prefix + 'codemirror/lib/codemirror.css');
+			// load_css(prefix + 'codemirror/addon/hint/show-hint.css');
+			// button
+			dolphinDB_button();
+			// js
+			// load_js(prefix + 'codemirror/lib/codemirror.js');
+			// load_js(prefix + 'codemirror/mode/sql/sql.js');
+			// load_js(prefix + 'codemirror/mode/python/python.js');
+			// load_js(prefix + 'codemirror/addon/hint/show-hint.js');
+			// load_js(prefix + 'codemirror/addon/hint/sql-hint.js');
         }
     };
 
